==> juce_4.1.0+repack.orig.tar.gz: JUCE-4.1.0/modules/juce_tracktion_marketplace/juce_tracktion_marketplace.cpp <==
/*
  ==============================================================================

   This file is part of the JUCE library.
   Copyright (c) 2015 - ROLI Ltd.

   Permission is granted to use this software under the terms of either:
   a) the GPL v2 (or any later version)
   b) the Affero GPL v3

   Details of these licenses can be found at: www.gnu.org/licenses

   JUCE is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   ------------------------------------------------------------------------------

   To release a closed-source product which uses JUCE, commercial licenses are
   available: visit www.juce.com for more information.

  ==============================================================================
*/

#if defined (JUCE_TRACKTION_MARKETPLACE_H_INCLUDED) && ! JUCE_AMALGAMATED_INCLUDE
 /* When you add this cpp file to your project, you mustn't include it in a file where you've
    already included any other headers - just put it inside a file on its own, possibly with your config
    flags preceding it, but don't include anything else. That also includes avoiding any automatic prefix
    header files that the compiler may be using.
 */
 #error "Incorrect use of JUCE cpp file"
#endif

// Your project must contain an AppConfig.h file with your project-specific settings in it,
// and your header search path must make it accessible to the module's files.
#include "AppConfig.h"

#include "juce_tracktion_marketplace.h"

namespace juce
{
    #include "marketplace/juce_OnlineUnlockStatus.cpp"
    #include "marketplace/juce_TracktionMarketplaceStatus.cpp"

   #if JUCE_MODULE_AVAILABLE_juce_gui_extra
    #include "marketplace/juce_OnlineUnlockForm.cpp"
   #endif
}

==> juce_4.3.0~repack.orig.tar.gz: JUCE-4.3.0/modules/juce_tracktion_marketplace/juce_tracktion_marketplace.cpp <==
/*
  ==============================================================================

   This file is part of the JUCE library.
   Copyright (c) 2015 - ROLI Ltd.

   Permission is granted to use this software under the terms of either:
   a) the GPL v2 (or any later version)
   b) the Affero GPL v3

   Details of these licenses can be found at: www.gnu.org/licenses

   JUCE is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   ------------------------------------------------------------------------------

   To release a closed-source product which uses JUCE, commercial licenses are
   available: visit www.juce.com for more information.

  ==============================================================================
*/

#ifdef JUCE_TRACKTION_MARKETPLACE_H_INCLUDED
 /* When you add this cpp file to your project, you mustn't include it in a file where you've
    already included any other headers - just put it inside a file on its own, possibly with your config
    flags preceding it, but don't include anything else. That also includes avoiding any automatic prefix
    header files that the compiler may be using.
 */
 #error "Incorrect use of JUCE cpp file"
#endif

#include "juce_tracktion_marketplace.h"

namespace juce
{
    #include "marketplace/juce_OnlineUnlockStatus.cpp"

   #if JUCE_MODULE_AVAILABLE_juce_data_structures
    #include "marketplace/juce_TracktionMarketplaceStatus.cpp"
   #endif

   #if JUCE_MODULE_AVAILABLE_juce_gui_extra
    #include "marketplace/juce_OnlineUnlockForm.cpp"
   #endif
}
